==> blesta-5.10.2.zip: blesta/plugins/download_manager/language/sv_se/download_manager_files.php <==
<?php
/**
 * Download Manager Files
 *
 * @package blesta
 * @subpackage blesta.language.sv_se
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['DownloadManagerFiles.!error.file_id.exists'] = 'Filen som uppdateras existerar inte.';
$lang['DownloadManagerFiles.!error.file_packages.format'] = 'Minst ett valt paket kan inte läggas till eftersom det inte existerar.';
$lang['DownloadManagerFiles.!error.permit_packages.format'] = 'Alternativet för pakettillgänglighet har ett ogiltigt format.';
$lang['DownloadManagerFiles.!error.file_groups.format'] = 'Minst en vald kundgrupp kan inte läggas till eftersom den inte existerar.';
$lang['DownloadManagerFiles.!error.permit_client_groups.format'] = 'Alternativet för kundgruppens tillgänglighet har ett ogiltigt format.';
$lang['DownloadManagerFiles.!error.public.assignment'] = 'Filen måste vara tillgänglig för antingen allmänheten, kundgrupper eller paket.';
$lang['DownloadManagerFiles.!error.public.format'] = 'Alternativet för allmän tillgänglighet har ett ogiltigt format.';
$lang['DownloadManagerFiles.!error.file_name.format'] = 'Ladda upp en fil eller ange en giltig sökväg till filen.';
$lang['DownloadManagerFiles.!error.name.empty'] = 'Ange ett namn för denna fil.';
$lang['DownloadManagerFiles.!error.company_id.exists'] = 'Ogiltigt företags-ID.';
$lang['DownloadManagerFiles.!error.category_id.exists'] = 'Vänligen välj en giltig kategori.';

==> blesta-5.11.4.zip: blesta/plugins/download_manager/language/sv_se/download_manager_files.php <==
<?php
/**
 * Download Manager Files
 *
 * @package blesta
 * @subpackage blesta.language.sv_se
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['DownloadManagerFiles.!error.file_id.exists'] = 'Filen som uppdateras existerar inte.';
$lang['DownloadManagerFiles.!error.file_packages.format'] = 'Minst ett valt paket kan inte läggas till eftersom det inte existerar.';
$lang['DownloadManagerFiles.!error.permit_packages.format'] = 'Alternativet för pakettillgänglighet har ett ogiltigt format.';
$lang['DownloadManagerFiles.!error.file_groups.format'] = 'Minst en vald kundgrupp kan inte läggas till eftersom den inte existerar.';
$lang['DownloadManagerFiles.!error.permit_client_groups.format'] = 'Alternativet för kundgruppens tillgänglighet har ett ogiltigt format.';
$lang['DownloadManagerFiles.!error.public.assignment'] = 'Filen måste vara tillgänglig för antingen allmänheten, kundgrupper eller paket.';
$lang['DownloadManagerFiles.!error.public.format'] = 'Alternativet för allmän tillgänglighet har ett ogiltigt format.';
$lang['DownloadManagerFiles.!error.file_name.format'] = 'Ladda upp en fil eller ange en giltig sökväg till filen i katalogen för uppladdningar.';
$lang['DownloadManagerFiles.!error.name.empty'] = 'Ange ett namn för denna fil.';
$lang['DownloadManagerFiles.!error.company_id.exists'] = 'Ogiltigt företags-ID.';
$lang['DownloadManagerFiles.!error.category_id.exists'] = 'Vänligen välj en giltig kategori.';
